# hello-8trider
- MY first python publish

##### view at:

### INSTALL
$ pip install hello-8trider

### DEV
$ git clone
$ cd hello-8trider
$ pdm venv create
$ source .venv/bin/activate
$ pdm install


### DEPLOY
$ pdm publish
